function ChangeInterv(interv, prefix, maxInterv) {
	var theForm = document.forms[0];
	if ((interv > 0) && (interv <= (maxInterv/2))) {
		var startWith = -1;
		for (var i = 0; i < maxInterv; i++) {
			var e = eval ("theForm." + prefix + i);
			if ((e.checked == true) && (startWith < 0)) {
				startWith = i % interv;
			}
//			alert ("startWith = " + startWith + "; i = " + i + "; interv = " + interv + "; i%interv = " + (i % interv));
			if ((i % interv) == startWith) { e.checked = true; }
			else { e.checked = false; }
		}
	}
}

function ChangeMinutes(field) {
	ChangeInterv(field.value, "min_", 60);
}

function ChangeHours(field) {
	ChangeInterv(field.value, "hour_", 24);
}

function ChangeDays(field) {
	ChangeInterv(field.value, "mday_", 31);
}

function ChangeMonths(field) {
	ChangeInterv(field.value, "month_", 12);
}

function ChangeWDays(field) {
	ChangeInterv(field.value, "wday_", 7);
}

function initsubmenu(imenu, isubmenu) {

	var theForm = document.forms[0];

	var smenu = theForm.s_menu;

	if (smenu == null) { return; }
	var menutext;
	for (var i = smenu.options.length - 1; i >= 0; i--) {
		smenu.options[i] = null;
	}

	smenu.selectIndex = 0;
	for (var i = 0; i <= menu.length - 1; i++) {
		menutext = menut[i];
		if (menu[i].length > 0) { menutext += " (" + menu[i] + ")"; }
		smenu.options[i] = new Option(menutext, menu[i]);
		if ((imenu == i) || (imenu == menu[i])) { smenu.selectedIndex = i; }
	}

	fsubmenu (smenu.selectedIndex, theForm, isubmenu);
}

function fsubmenu(imenu, theForm, isubmenu) {
	var smenu = theForm.s_submenu;
	var menutext;
//	if (smenu == "home")
	if (menu[imenu] == "menupage") {
		theForm._nextpage.value = "menupage";
		theForm.submit ();
	}
	else {
		for (var i = smenu.options.length - 1; i >= 0; i--) {
			smenu.options[i] = null;
		}
 
		for (var i = 0; i <= submenu[imenu].length - 1; i++) {
			menutext = submenut[imenu][i];
			if (submenu[imenu][i].length > 0) { menutext += " (" + submenu[imenu][i] + ")"; }
			smenu.options[i] = new Option(menutext,submenu[imenu][i]);
			if ((isubmenu == i) || (isubmenu == submenu[imenu][i])) { smenu.selectedIndex = i; }
		}
	}
}

function ValidateMenu (imenu, theForm) {
	var smenu = theForm.s_menu;
	var ssubmenu = theForm.s_submenu;

	var notyetmenus = new Array ( "tools.patch" );

	var currmenu = smenu[smenu.selectedIndex].value;
	var currsubmenu = ssubmenu[ssubmenu.selectedIndex].value;

	var mSm = currmenu + "." + currsubmenu;
	for (var i = 0; i < notyetmenus.length; i++) {
		if (notyetmenus[i] == mSm) {
			alert ("This module is not yet ready , Sorry");
			return;
		}
	}

	theForm._currmenu.value = currmenu;
	theForm._currsubmenu.value = currsubmenu;
	theForm._nextpage.value = currsubmenu;
	theForm._nextaction.value = '';
	theForm._actiondetail.value = '';
	if (theForm._objectid) { theForm._objectid.value = ''; }

	theForm.submit ();
}

/* Objet CafFields 
*/
function CafField (phElement, pfName, pfType, pfMand, pfMin, pfMax, pisList, pdependOn) {
	this.fHandle = phElement;
	this.fName = pfName;
	this.fType = pfType;
	this.fMand = pfMand;
	this.fMin = pfMin;
	this.fMax = pfMax;
	this.isList = pisList;
	this.dependOn = pdependOn;

	this.CafInteger = CafInteger;
	this.CafNumber  = CafNumber;
	this.CafDate    = CafDate;
	this.CafDateTime = CafDateTime;
	this.CafTime     = CafTime;
	this.CafAtom     = CafAtom;
}

function CafFields () {
	this.fCount = 0;
	this.FieldsArray = new Array ();
	this.hForm = document.forms[0];
	this.AddCafField = AddCafField;
	this.CheckCafFields = CheckCafFields;
}

function AddCafField (pfName, pfType, pfMand, pfMin, pfMax, pisList, pdependOn) {
	var fElements = this.hForm.elements;
	var hElement;
	var i;
	for (i = 0; i < fElements.length; i++) {
		if (pfName == fElements[i].name) { hElement = fElements[i]; break; }
	}
	if (i > fElements.length) { alert("AddCafField : Field " + pfName + " Not defined !"); }

	this.FieldsArray[this.fCount] = CafField (hElement, pfName, pfType, pfMand, pfMin, pfMax, pisList, pdependOn);
	this.fCount++;
}

function CheckCafFields () {
}

function CafInteger () {
}

function CafNumber () {
}

function CafDateTime () {
}

function CafDate () {
}

function CafTime () {
}

function CafAtom () {
}


function EditScript3 (callerPage, relatedObject) {
	var winName, newWin, winId, hForm, sessionId;
	hForm = document.mainform;
	var srcKind = hForm.scriptlist.value;
	var scrLang = hForm.scriptlang.value
	EditScript2 (callerPage, relatedObject, srcKind, scrLang);
}

function EditScript2 (callerPage, relatedObject, scrKind, scrLang) {
	// var fldsArray = returnFields.split(";")
	var winName, newWin, winId, hForm, sessionId;
	hForm = document.mainform;
	// hForm.elements[0].style.cursor = "wait";

	sessionId = hForm._sessionid.value;
	var returnFields = "script_id-script_name";
	var evalstring = "hForm.script_id";
	var e = eval (evalstring);
	var scriptId = e.value;
	winSearchId = hForm._winsearchid.value;

	if (winSearchId) { winSearchId++; }
	else { winSearchId = 1; }

	var cmd = "index.pl?_sessionid=" + sessionId + "&_nextpage=scriptse";
	cmd += "&_nextaction=generate&_actiondetail=edit&_searchcall=yes&_returnfields=" + returnFields;
	cmd += "&__param__0=" + scriptId + "&__param__1=" + scrKind + "&__param__2=" + scrLang + "&__param__3=" + relatedObject;
	cmd += "&_winsearchid=" + winSearchId;
	if (callerPage) { cmd += "&_callerpage=" + callerPage; }

	
	winName = "CafeterraSearch" + winSearchId;
	// hForm.elements[0].style.cursor = "wait";
	newWin=open(cmd,winName,"Scrollbars=1,resizable=1,screenX=1,screenY=1,width=800,height=400,status=1");
	if (newWin.opener == null) newWin.opener = self;
	newWin.focus();
	// hForm.elements[0].style.cursor = "auto";
}

function EditScript (callerPage, relatedObject, iLine, scrKind, scrLang) {
	// var fldsArray = returnFields.split(";")
	var winName, newWin, winId, hForm, sessionId;
	hForm = document.mainform;
	// hForm.elements[0].style.cursor = "wait";

	sessionId = hForm._sessionid.value;
	var returnFields = "script_id_" + iLine + "-script_name_" + iLine;
	var evalstring = "hForm.script_id_" + iLine;
	var e = eval (evalstring);
	var scriptId = e.value;
	winSearchId = hForm._winsearchid.value;

	if (winSearchId) { winSearchId++; }
	else { winSearchId = 1; }

	var cmd = "index.pl?_sessionid=" + sessionId + "&_nextpage=scriptse";
	cmd += "&_nextaction=generate&_actiondetail=edit&_searchcall=yes&_returnfields=" + returnFields;
	cmd += "&__param__0=" + scriptId + "&__param__1=" + scrKind + "&__param__2=" + scrLang + "&__param__3=" + relatedObject;
	cmd += "&_winsearchid=" + winSearchId;
	if (callerPage) { cmd += "&_callerpage=" + callerPage; }

	
	winName = "CafeterraSearch" + winSearchId;
	// hForm.elements[0].style.cursor = "wait";
	newWin=open(cmd,winName,"Scrollbars=1,resizable=1,screenX=1,screenY=1,width=800,height=400,status=1");
	if (newWin.opener == null) newWin.opener = self;
	newWin.focus();
	// hForm.elements[0].style.cursor = "auto";
}

function EditSubFlow (nextPage, nextAction, flowId, subflowId) {
	var theForm = document.forms[0];
	theForm._nextpage.value = nextPage;
	theForm._nextaction.value = nextAction;
	theForm._actiondetail.value = 'edit';
//	theForm.object_id.value = flowId;
	var e2 = eval ("theForm.object_id");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "object_id";
		theForm.appendChild(e2);
	}
	e2.value = flowId
	e2 = eval ("theForm.subflow_id");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "subflow_id";
		theForm.appendChild(e2);
	}
	e2.value = subflowId
	theForm.submit();
}

function ValidateAndSubmit (nextPage, nextAction, actionDetail, objectId) {
	var theForm = document.forms[0];
	theForm._nextpage.value = nextPage;
	theForm._nextaction.value = nextAction;
	theForm._actiondetail.value = actionDetail;
	
//alert ("_objectid = " + theForm._objectid);
	if (objectId) {
		e2 = eval ("theForm._objectid");
		if (e2 == null) {
			e2 = document.createElement("input");
			e2.type = "hidden";
			e2.name = "_objectid";
			theForm.appendChild(e2);
		}
		e2.value = objectId;
	}
//	if (objectId) { theForm._objectid.value = objectId; }
	theForm.submit();
}

function CreateImportParameters (iContainer) {
	var theForm = document.forms[0];
	var e1 = eval ("theForm.object_id_" + iContainer);
	if (e1 != null) {
		var e2 = eval ("theForm._selectedoid");
		if (e2 == null) {
			e2 = document.createElement("input");
			e2.type = "hidden";
			e2.name = "_selectedoid";
			theForm.appendChild(e2);
		}
		e2.value = e1.value;
	}
	e1 = eval ("theForm.name_" + iContainer);
	e2 = eval ("theForm._selectedname");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "_selectedname";
		theForm.appendChild(e2);
	}
	e2.value = e1.value;
	e1 = eval ("theForm.externalname_" + iContainer);
	e2 = eval ("theForm._selectedexternalname");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "_selectedexternalname";
		theForm.appendChild(e2);
	}
	e2.value = e1.value;
	e1 = eval ("theForm.type_" + iContainer);
	e2 = eval ("theForm._selectedtype");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "_selectedtype";
		theForm.appendChild(e2);
	}
	e2.value = e1.value;
	e1 = eval ("theForm.owner_" + iContainer);
	e2 = eval ("theForm._selectedowner");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "_selectedowner";
		theForm.appendChild(e2);
	}
	e2.value = e1.value;
	e1 = eval ("theForm.remarks_" + iContainer);
	e2 = eval ("theForm._selectedremarks");
	if (e2 == null) {
		e2 = document.createElement("input");
		e2.type = "hidden";
		e2.name = "_selectedremarks";
		theForm.appendChild(e2);
	}
	e2.value = e1.value;
}

function ValidateImportContainer(nextPage, nextAction, actionDetail, iContainer) {
	var theForm = document.forms[0];
	theForm._nextpage.value = nextPage;
	theForm._nextaction.value = nextAction;
	theForm._actiondetail.value = actionDetail;
	if (actionDetail != 'selected') {
		CreateImportParameters(iContainer);
	}
//	if (objectId) { theForm._objectid.value = objectId; }
	theForm.submit();
}

function ValidateImportFields(nextPage, nextAction, iContainer) {
	var theForm = document.forms[0];
	theForm._nextpage.value = nextPage;
	theForm._nextaction.value = nextAction;
	theForm._actiondetail.value = 'search';
	if (nextAction == 'search') { CreateImportParameters(iContainer); }
//	if (objectId) { theForm._objectid.value = objectId; }
	theForm.submit();
//	e1 = eval ("theForm.remarks_" + iContainer);
	if (actionDetail == 'update') {
		var e2 = eval ("theForm.updateexisting");
		if (e2 == null) {
			e2 = document.createElement("input");
			e2.type = "hidden";
			e2.name = "updateexisting";
			theForm.appendChild(e2);
		}
		e2.value = "ON";
	}
}

function LFieldImportContainer () {
	var theForm = document.forms[0];
	theForm.submit();
}

function OpenChild(callerPage, calledPage, hiddenLabel, searchCriteria, searchCriteria0) {
	var theForm = document.forms[0];
	theForm._nextpage.value = calledPage;
	theForm._nextaction.value = 'search';
	theForm._actiondetail.value = 'search';
	if (calledPage == "fieldt") { theForm._nextaction.value = 'edite'; }
	var h = "_this" + hiddenLabel;
	var h0 = "_this" + hiddenLabel + "0";
	var e = eval ("theForm." + h);
	if (e == null) {
		var x;
		x = document.createElement("input");
		x.type = "hidden";
		x.value = "" + searchCriteria;
		x.name = h;
		theForm.appendChild(x);
	}
	else {
		eval ("theForm." + h + ".value =  searchCriteria");
	}

	var e0 = eval ("theForm." + h0);
	if (e0 == null) {
		var y;
		y = document.createElement("input");
		y.type = "hidden";
		y.name = h0;
		y.value = "" + searchCriteria0;
		theForm.appendChild(y);
	}
	else {
		eval ("theForm." + h0 + ".value =  searchCriteria0");
	}
//	eval ("alert(theForm."+h0+".name + ' = ' + theForm."+h0+".value)")
//	eval ("alert( theForm."+h+".name + ' = ' + theForm."+h+".value)")
//	if ((objectId) ) { theForm._objectid.value = objectId; }
	theForm.submit();
}

function OpenChooser (callerPage, calledPage, returnFields, searchCriteria) {

	// var fldsArray = returnFields.split(";")
	var winName, newWin, winId, hForm, sessionId;
	hForm = document.mainform;
	// hForm.elements[0].style.cursor = "wait";

	sessionId = hForm._sessionid.value;
	
	winSearchId = hForm._winsearchid.value;

	if (winSearchId) { winSearchId++; }
	else { winSearchId = 1; }

	var cmd = "index.pl?_sessionid=" + sessionId + "&_nextpage=" + calledPage;
	cmd += "&_nextaction=search&_searchcall=yes&_returnfields=" + returnFields;
	//cmd += "&_searchCriteria=" + searchCriteria;
	cmd += "&_winsearchid=" + winSearchId;
	if (callerPage) { cmd += "&_callerpage=" + callerPage; }
	if (searchCriteria) { cmd += "&_searchCriteria=" + searchCriteria; }

	// var i = 0;
	// while (fldsArray[i]) { cmd += "&_returnfld" + i + fldsArray[i]; i++; }
	
	winName = "CafeterraSearch" + winSearchId;
	// hForm.elements[0].style.cursor = "wait";
	newWin=open(cmd,winName,"Scrollbars=1,resizable=1,screenX=1,screenY=1,width=900,height=600,status=1");
	if (newWin.opener == null) newWin.opener = self;
	newWin.focus();
	// hForm.elements[0].style.cursor = "auto";
}

function OpenChooserContainer (callerPage, iField, dir, searchCriteria) {
	var returnFields;
	returnFields = dir + "container_id_" + iField + "-" + dir + "container_name_" + iField;
	OpenChooser(callerPage, 'containerl', returnFields, searchCriteria);
}

function OpenChooserScripts3 (callerPage, type, searchCriteria) {
	var hForm = document.mainform;
	var type = hForm.scriptlist.value;
	var returnFields = "script_id-script_name";
	OpenChooser(callerPage, 'scriptsl', returnFields, searchCriteria);
}

function OpenChooserScripts2 (callerPage, type, searchCriteria) {
	var returnFields;
	returnFields = "script_id-script_name";
	OpenChooser(callerPage, 'scriptsl', returnFields, searchCriteria);
}

function OpenChooserScripts (callerPage, iField, type, searchCriteria) {
	var returnFields;
	returnFields = "script_id_" + iField + "-" + "script_name_" + iField;
	OpenChooser(callerPage, 'scriptsl', returnFields, searchCriteria);
}

function SelectThis(v0, v1, v2, v3, v4) {
	var fldsString = document.mainform._returnfields.value;
	var fldsArray = fldsString.split("-");

	if(v0 != null) { v0.replace("/&#squote;/", "'"); }
	if(v1 != null) { v1.replace("/&#squote;/", "'"); }
	if(v2 != null) { v2.replace("/&#squote;/", "'"); }
	if(v3 != null) { v3.replace("/&#squote;/", "'"); }
	if(v4 != null) { v4.replace("/&#squote;/", "'"); }
	var fieldObject;
	var i = fldsArray.length - 1;
	var ee;
	opener.focus();
	while ((i >= 0) && (fldsArray[i])) { 
		var evalStr1 = "opener.document.mainform." + fldsArray[i];
		var e = eval (evalStr1);
		if (e != null) {
			var evalStr2 = evalStr1 + ".value = " + "v" + i;
			if (i == 0) { ee=e; }
			eval (evalStr2);
		}
		i--;
	}
	if (ee != null) { eval ("ee.focus()"); }

//	window.close();
}
/*
*/
function ResetFields (theFormx) {
	var theForm = document.forms[0];
	theForm.reset();
}

function ShowHelp (page) {
//	alert ("Show Help " + myLabel + "  (" + page + ")");
	alert ("Sorry Help is planned and is comming soon");
}


function ChangedSFField() {
	var theForm = document.forms[0];
	var theList = theForm.outgofields;
	var index = theList.selectedIndex;
	var currField;
	currField = eval('theForm._index');
	if (currField == null) {
		currField = document.createElement("input");
		currField.type = "hidden";
		currField.name = "_index";
		currField.value = -1;
		theForm.appendChild(currField);
	}
	if ((currField.value -1) != index) {
		theForm._index.value = index + 1;
		currFName = theList.options[index].text;
		var val = eval('theForm.outgofield_id_' + index + '.value');
		theForm.outgofield_id.value = val;
		currFName = currFName.substr(currFName.indexOf('- ') + 2);
		theForm.outgofield_name.value =  currFName;
// #?if eq;self._subflow.flowdirection;"outgo"?#
		var incomField = eval('theForm.incomfield_id_' + index);
		if (incomField != null) {
			var incomIndex = incomField.value;
			var incomList = eval('theForm.incomfields');
			for (var i = 0; i < incomList.options.length; i++) {
				if (incomList.options[i].value == incomIndex) { incomList.selectedIndex = i; break; }
			}
		}
// #?endif eq;self._subflow.flowdirection;"outgo"?#
		theForm.formula.value = eval('theForm.formula_' + index + '.value');
		theForm.script_id.value = eval('theForm.script_id_' + index + '.value');
		theForm.script_name.value = eval('theForm.script_name_' + index + '.value');
	}
}

function ChangedMappingPopup(theList, destField1, destField2) {
	var theForm = document.forms[0];
	var index = theList.selectedIndex;

	var iLine = theForm._index.value - 1
	if (iLine == null) { return; }
	var destF = "theForm." + destField1 + "_" + iLine;
	var e = eval(destF);
	if (e != null) {
		e.value = theList.options[index].value;
	}

	if (destField2 != null) {
		destF = "theForm." + destField2 + "_" + iLine;
		var e = eval(destF);
		if (e != null) {
			var t = theList.options[index].text;
			e.value = t.substr(t.indexOf("- ") + 2);
		}
	}
}

function ChangedMappingInput(srcField1, srcField2) {
	var theForm = document.forms[0];

	var iLine = theForm._index.value - 1;
	if (iLine == null) { return; }
	var s = eval("theForm." + srcField1);
	if (s != null) {
		var d = eval("theForm." + srcField1 + "_" + iLine);
		if (d != null) { d.value = s.value; }
	}

	if (srcField2 != null) {
		s = eval("theForm." + srcField2);
		if (s != null) {
			var d = eval("theForm." + srcField2 + "_" + iLine);
			if (d != null) { d.value = s.value; }
		}
	}
}

var FLDTtexts = new Array ("object_id_", "name_", "externalname_", "objectlabel_", "datalength_", "datascale_", "fieldorder_",
	"fieldpos_", "keyposition_", "dataformat_", "defaultvalue_", "comments_", "remarks_");
var FLDTselects = new Array ("datatypeid_", "status_");
var FLDTchecks = new Array ("nullable_", "localfield_");
function FLDTListChanged() {
	var theForm = document.forms[0];
	var theList = theForm.fields;
	var index = theList.selectedIndex;
	var currField;
	currField = eval('theForm._index');
	if (currField == null) {
		currField = document.createElement("input");
		currField.type = "hidden";
		currField.name = "_index";
		currField.value = -1;
		theForm.appendChild(currField);
	}

	var texts = FLDTtexts;
	var selects = FLDTselects;
	var checks = FLDTchecks;

	if ((currField.value -1) != index) {
		currField.value = index + 1;
//		theForm._index.value = index + 1;
//		currFName = theList.options[index].text;
		for (var i = 0; i < texts.length; i++) {
			os = eval("theForm." + texts[i] + index);
			od = eval("theForm." + texts[i]);
			if ((os != null) && (od != null))  {
				od.value = os.value;

			}
		}
		for (var i = 0; i < selects.length; i++) {
			os = eval("theForm." + selects[i] + index);
			od = eval("theForm." + selects[i]);
			if ((os != null) && (od != null))  {
				od.selectedIndex = os.selectedIndex;
			}
		}
		for (var i = 0; i < checks.length; i++) {
			os = eval("theForm." + checks[i] + index);
			od = eval("theForm." + checks[i]);
			if ((os != null) && (od != null))  {
				od.checked = os.checked;
			}
		}

	}
}

function InArray (item, arr) {
	for (var i = 0; i < arr.length; i++) {
		if (item == arr[i]) { return (true); }
	}
	return (false);
}

function FLDTChangedInput (object, theIndex) {
	var theForm = document.forms[0];
	var theList = theForm.fields;
	var index = theList.selectedIndex;
	var name = object.name;
	var od;
	if (theIndex != null) {
		index = theIndex;
		theList.selectedIndex = index;
		name = name.substr(0, name.indexOf(index));
		FLDTListChanged();
		od = eval ("theForm." + name);
	}
	else { od = eval ("theForm." + object.name + index); }

	var texts = FLDTtexts;
	var selects = FLDTselects;
	var checks = FLDTchecks;

	if (name == "name_") {
		var value = theList.options[index].value;
		if ((value == null) || (value == "")) { value = "-NEW-"; }
		theList.options[index].text = object.value + " (" + value + ")";
	}

	oc = eval ("theForm.checked_" + index);
	if (od != null) {
		if (InArray(object.name,texts)) { od.value = object.value; oc.checked=true; }
		else {
			if (InArray(object.name,selects)) { od.selectedIndex = object.selectedIndex; }
			else {
				if (InArray(object.name,checks)) { od.checked = object.checked; }
			}
		}
		if (oc != null) { oc.checked=true; }
	}
}

SFInput = new Array("object_id_", "name_", "objectlabel_", "floworder_", "container_id_", "container_name_");
SFCheckBox = new Array("keepalive_", "mailonerr_", "mailonsucc_");
SFPopup = new Array("status_", "onoutgoerr_", "flowmethod_");
var SFOldDir = 0;

function OpenChooserContainer2 (callerPage, searchCriteria) {
	var theForm = document.forms[0];

	if (SFOldDir == 0) {
		return;
	}

	var dirList = theForm.direction_;
	var dir = dirList.options[dirList.selectedIndex].value;
	var dir = dir.substr(1,1);;
	var theList;
	var iField;

	if (dir == 'i') {
		theList = theForm.incomflows;
	}
	else {
		theList = theForm.outgoflows;
	}
	iField = theList.selectedIndex;

//	OpenChooserContainer(callerPage, dir, iField, searchCriteria);
	var returnFields = "container_id_-container_name_";
	OpenChooser(callerPage, 'containerl', returnFields, searchCriteria);
}

function EditSubFlow2 (nextPage, nextAction, flowId) {
	var theForm = document.forms[0];
	
	if ((SFOldDir == 0) || (theForm.object_id_.value == null) || (theForm.object_id_.value <= 0)) {
		return;
	}

	EditSubFlow (nextPage, nextAction, flowId, theForm.object_id_.value);
}

function SFDirectionChanged () {
	var theForm = document.forms[0];
	var theList = theForm.direction_;
	var index = theList.selectedIndex;

	theList.selectedIndex = SFOldDir;
}

function SFListChanged(dir) {
	var theForm = document.forms[0];
	var dirList = theForm.direction_;
	var oldDir = dirList.selectedIndex;
	var prefix;
	var theList;

	if (dir == 'incom') {
		theForm.outgoflows.selectedIndex = -1;
		theList = theForm.incomflows;
		dirList.selectedIndex = 1;
		prefix="i";
	}
	else {
		theForm.incomflows.selectedIndex = -1;
		theList = theForm.outgoflows;
		dirList.selectedIndex = 2;
		prefix="o";
	}
	
	SFOldDir = dirList.selectedIndex;

	if (oldDir != dirList.selectIndex) {
		var methods = translate(dir + "meth");
		for (var i = theForm.flowmethod_.length; i >= 0; i --) {
			theForm.flowmethod_.options[i] = null;
		}
		for (var i = 0; i < methods.length; i++) {
			theForm.flowmethod_.options[i] = new Option(translate(methods[i]), methods[i]);
		}
	}

	var index = theList.selectedIndex;

	for (i = 0; i < SFInput.length; i++) {
		od = eval("theForm." + SFInput[i]);
		os = eval("theForm." + prefix + SFInput[i] + index);
		od.value = os.value;
	}

	for (i = 0; i < SFCheckBox.length; i++) {
		od = eval("theForm." + SFCheckBox[i]);
		os = eval("theForm." + prefix + SFCheckBox[i] + index);
		if (SFCheckBox[i] == 'keepalive_') { od.checked = os.checked; }
		else {
			if (os.value == 'yes') { od.checked = true; }
			else { od.checked = false; }
		}
	}

	for (i = 0; i < SFPopup.length; i++) {
		od = eval("theForm." + SFPopup[i]);
		os = eval("theForm." + prefix + SFPopup[i] + index);
		od.selectedIndex = os.selectedIndex;
	}
}


function SFChangedInput (dir, object, theIndex) {
	var theForm = document.forms[0];
	var dirList = theForm.direction_;
	var theList;
	var name = object.name;
	var od;

	var texts = SFInput;
	var selects = SFPopup;
	var checks = SFCheckBox;

	if (dir == null) {
		dir = dirList.options[dirList.selectedIndex].value;
	}
	if (dir == 'incom') {
		theForm.outgoflows.selectedIndex = -1;
		theList = theForm.incomflows;
		dirList.selectedIndex = 1;
		prefix="i";
	}
	else {
		if (dir == 'outgo') {
		theForm.incomflows.selectedIndex = -1;
		theList = theForm.outgoflows;
		dirList.selectedIndex = 2;
		prefix="o";
		}
		else { return; }
	}
	if (theIndex != null) { SFListChanged(dir); }
	index = theList.selectedIndex;

	if (theIndex != null) {
		index = theIndex;
		theList.selectedIndex = index;
		name = name.substr(1, name.indexOf(index) - 1);
		SFListChanged(dir);
		od = eval ("theForm." + name);
	}
	else { od = eval ("theForm." + prefix + object.name + index); }

	if (name == "name_") {
		var value = theList.options[index].value;
		if ((value == null) || (value == "")) { value = "-NEW-"; }
		theList.options[index].text = object.value.substr(0, 10) + "( " + value + " )";
	}

	if (InArray(name,texts)) { od.value = object.value; }
	else {
		if (InArray(name,selects)) { od.selectedIndex = object.selectedIndex; }
		else {
			if (InArray(name,checks)) {
				od.checked = object.checked;
				if (name == 'keepalive_') { od.checked = object.checked; }
				else {
					if (theIndex != null) { od.checked = (object.value == 'yes' ? true : false); }
					else { od.value = (od.checked ? 'yes' : 'no'); }
				}
			}
		}
	}
}




SCRInput = new Array("script_id", "script_name");
SCRPopup = new Array("usedfor");

function ChangedSCRList(force) {
	var theForm = document.forms[0];
	var theList = theForm.scriptlist;
	var index = theList.selectedIndex;
	var currField;
	currField = eval('theForm._index');
	if (currField == null) {
		currField = document.createElement("input");
		currField.type = "hidden";
		currField.name = "_index";
		currField.value = - 1;
		theForm.appendChild(currField);
	}
	if (((currField.value - 1) != index) || (force == 1)) {
		theForm._index.value = index + 1;
		currFName = theList.options[index].text;
		theForm.script_id.value = eval('theForm.script_id_' + index + '.value');
		theForm.script_name.value = eval('theForm.script_name_' + index + '.value');
		theForm.usedfor.value = eval('theForm.usedfor_' + index + '.value');
		theForm.scriptlang.value = eval('theForm.scriptlang_' + index + '.value');
	}
}

function ChangedSCRInput (object, theIndex) {
	var theForm = document.forms[0];
	var theList = theForm.scriptlist;
	var index = theList.selectedIndex;
	var name = object.name;
	var od, os2, od2;
	if (theIndex != null) {
		index = theIndex;
		theList.selectedIndex = index;
		name = name.substr(0, name.indexOf(index));
		ChangedSCRList(1);
	}
	else {
		od = eval ("theForm.script_id_" + index);
		od.value = theForm.script_id.value;
		od = eval ("theForm.script_name_" + index);	
		od.value = theForm.script_name.value;
		od = eval ("theForm.usedfor_" + index);	
		od.selectedIndex = theForm.usedfor.selectedIndex;
	}
}







